# pyrobinhood
A robinhood client for python

# Test
- Login to robinhood in your browser and grab your bearer token from any request.
- `> pip install -r requirements.txt`
- `> export RB_TOKEN={your_bearer_token}`
- `> export RB_REFRESH_TOKEN={your_refresh_token}`
- `> export RB_CLIENT_ID={your_client_id}`
- `> make test`
